@@ -28,7 +28,7 @@ static int conv(
   *resp = malloc(num_msg * sizeof(**resp));
   for (i = 0; i < num_msg; i += 1)
   {
-    (*resp)[i].resp = (char*)(*msg)[i].msg;
+    (*resp)[i].resp = strdup((*msg)[i].msg);
     (*resp)[i].resp_retcode = (*msg)[i].msg_style;
   }
   return 0;
