@@ -1,10 +1,26 @@
 /*
- * Copyright (c) 2007,2009,2010,2011,2012 Russell Stuart
+ * Copyright (c) 2007-2012,2014 Russell Stuart
  *
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published
+ * by the Free Software Foundation, either version 3 of the License, or (at
+ * your option) any later version.
+ *
+ * The copyright holders grant you an additional permission under Section 7
+ * of the GNU Affero General Public License, version 3, exempting you from
+ * the requirement in Section 6 of the GNU General Public License, version 3,
+ * to accompany Corresponding Source with Installation Information for the
+ * Program or any work based on the Program. You are still required to
+ * comply with all other Section 6 requirements to provide Corresponding
+ * Source.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define PAM_SM_AUTH
@@ -37,8 +53,15 @@
 
 #define arr_size(x)	(sizeof(x) / sizeof(*(x)))
 
-const char libpam_python_version[]	= "1.0.2";
-const char libpam_python_date[]		= "2012-04-12";
+const char libpam_python_version[]	= "1.0.3";
+const char libpam_python_date[]		= "2014-05-05";
+
+/*
+ * Add typedef for Py_ssize_t if it you have an older python.
+ */
+#if (PY_VERSION_HEX < 0x02050000)
+typedef int Py_ssize_t;
+#endif
 
 /*
  * The python interpreter's shared library.
@@ -1670,7 +1693,9 @@ static PyGetSetDef PamHandle_Getset[] =
   CONSTANT_GETSET(PAM_USER),
   CONSTANT_GETSET(PAM_USER_PROMPT),
   CONSTANT_GETSET(PAM_USER_UNKNOWN),
+#ifdef  PAM_XAUTHDATA
   CONSTANT_GETSET(PAM_XAUTHDATA),
+#endif
 #ifdef	PAM_XDISPLAY
   CONSTANT_GETSET(PAM_XDISPLAY),
 #endif
@@ -2258,7 +2283,11 @@ static PyTypeObject* newHeapType(
   type->tp_members = members;
   type->tp_getset = getset;
   type->tp_name = PyString_AsString(pyName);
+#if PY_VERSION_HEX < 0x02050000
+  ((PyHeapTypeObject*)type)->name = pyName;
+#else
   ((PyHeapTypeObject*)type)->ht_name = pyName;
+#endif
   pyName = 0;
   PyType_Ready(type);
   type->tp_new = new;
@@ -2367,7 +2396,7 @@ static int get_pamHandle(
   {
     pam_result = syslog_path_message(
         module_path,
-	"Can't load python library %s: %s", libpython_so, strerror(errno));
+	"Can't load python library %s: %s", libpython_so, dlerror());
     goto error_exit;
   }
   do_initialize = pypam_initialize_count > 0 || !Py_IsInitialized();
