@@ -1,13 +1,15 @@
 #!/usr/bin/python -W default
 import warnings; warnings.simplefilter('default')
+
+import distutils.sysconfig
+import os 
+import sys
+
 try:
   from setuptools import setup, Extension
 except ImportError:
   from distutils.core import setup, Extension
 
-import sys
-import os 
-
 long_description = """\
 Embeds the Python interpreter into PAM \
 so PAM modules can be written in Python"""
@@ -15,7 +17,7 @@ so PAM modules can be written in Python"""
 classifiers = [
   "Development Status :: 4 - Beta",
   "Intended Audience :: Developers",
-  "License :: OSI Approved :: EPL",
+  "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
   "Natural Language :: English",
   "Operating System :: Unix",
   "Programming Language :: C",
@@ -28,7 +30,7 @@ if not os.environ.has_key("Py_DEBUG"):
 else:
   Py_DEBUG = [('Py_DEBUG',1)]
 
-libpython_so = ('libpython%d.%d.so.1') % sys.version_info[:2]
+libpython_so = distutils.sysconfig.get_config_var('INSTSONAME')
 ext_modules = [
     Extension(
       "pam_python",
@@ -41,15 +43,15 @@ ext_modules = [
 
 setup(
   name="pam_python",
-  version="1.0.2",
+  version="1.0.4",
   description="Enabled PAM Modules to be written in Python",
   keywords="pam,embed,authentication,security",
   platforms="Unix",
   long_description=long_description,
   author="Russell Stuart",
   author_email="russell-pampython@stuart.id.au",
-  url="http://www.stuart.id.au/russell/files/pam_python",
-  license="EPL",
+  url="http://pam-python.sourceforge.net/",
+  license="AGPL-3.0",
   classifiers=classifiers,
   ext_modules=ext_modules,
 )
