@@ -50,7 +50,7 @@ def run_test(caller):
   caller(test.test_results)
   sys.stdout.write("OK\n")
 
-def pam_conv(auth, query_list, userData):
+def pam_conv(auth, query_list, userData=None):
   return query_list
 
 #
